@@ -1,6 +1,6 @@
 /* 
  *      XSitecopy, for managing remote web sites with a GNOME interface.
- *      Copyright (C) 1999, Lee Mallabone <lee0@callnetuk.com>
+ *      Copyright (C) 2000, Lee Mallabone <lee0@callnetuk.com>
  *                                                                        
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -18,15 +18,11 @@
  *  
  */
 
+#ifndef FILE_WIDGETS_H
+#define FILE_WIDGETS_H
+
 #include <gnome.h>
+GtkWidget *make_file_info_area(struct site_file *the_file);
 
-struct labelled_entry {
-   GtkWidget *entry;
-   GtkWidget *label;
-   gchar *label_text;
-   gchar *entry_default;
-   gboolean editable;
-};
+#endif  /* FILE_WIDGETS_H */
 
-GtkWidget *create_label_and_entry (struct labelled_entry *the_data);   
-GtkWidget *make_file_info_area (struct site_file_t *the_file);
