@@ -1,6 +1,6 @@
 /* 
  *      XSitecopy, for managing remote web sites with a GNOME interface.
- *      Copyright (C) 1999, Lee Mallabone <lee0@callnetuk.com
+ *      Copyright (C) 2000, Lee Mallabone <lee0@callnetuk.com
  *                                                                        
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -18,7 +18,16 @@
  *  
  */
 #include <gnome.h>
+#include <unistd.h>
+#include <sys/stat.h>
+#include "config.h"
+#include "misc.h"
+#include "operations.h"
+#include "resynch.h"
+#include "new_site.h"
+#include "rcfile.h"
+#include "common.h"
 
-int create_about (void);
+int create_about(void);
 int create_main_window(void);
-int fe_gnome_init (void);
+int xsitecopy_read_configuration(void);
