@@ -1,6 +1,6 @@
 /* 
  *      XSitecopy, for managing remote web sites with a GNOME interface.
- *      Copyright (C) 1999, Lee Mallabone <lee0@callnetuk.com
+ *      Copyright (C) 2000, Lee Mallabone <lee0@callnetuk.com
  *                                                                        
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -21,16 +21,23 @@
 #ifndef GNOME_RESYNC_H
 #define GNOME_RESYNC_H
 
+#include <semaphore.h>
 #include <pthread.h>
 #include <stdio.h>
 #include <gnome.h>
 #include "sites.h"
 #include "rcfile.h"
+#include "gcommon.h"
+#include "misc.h"
+#include "operations.h"
 
-int fetch_site_list_please (GtkWidget *update_button, gpointer data);
-void close_fetch_window (void);
-int start_fetch_list (void);
-void *actual_fetch_list (void *nothing);
-void fe_fetch_found( const struct site_file_t *file );
+gboolean delete_fetch(GtkWindow *fnar, gpointer data);
+int fetch_site_list_please(GtkWidget * update_button, gpointer data);
+void close_fetch_window(void);
+int start_fetch_list(void);
+void *fetch_thread(void *no_data);
+void *actual_fetch_list(void *nothing);
+void fe_fetch_found(const struct site_file *file);
+void *sync_thread(void *no_data);
 
-#endif
+#endif				/* GNOME_RESYNC_H */
