@@ -1,6 +1,6 @@
 /* 
  *      XSitecopy, for managing remote web sites with a GNOME interface.
- *      Copyright (C) 1999, Lee Mallabone <lee0@callnetuk.com
+ *      Copyright (C) 2000, Lee Mallabone <lee0@callnetuk.com
  *                                                                        
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -18,11 +18,16 @@
  *  
  */
 
-#include <gtk/gtk.h>
-
 #ifndef FE_GTK_SITE_WIDGETS_H
 #define FE_GTK_SITE_WIDGETS_H
 
-GtkWidget *make_site_info_area (struct site_t *the_site);
+#include <gtk/gtk.h>
+#include "rcfile.h"
+#include "misc.h"
+#include "gcommon.h"
+#include "changes.h"
+#include "minilist.h"
 
-#endif /* FE_GTK_SITE_WIDGETS_H */
+GtkWidget *make_site_info_area(struct site *the_site);
+
+#endif				/* FE_GTK_SITE_WIDGETS_H */
